@@ -88,6 +88,12 @@ def update():
         ip_str = "[×] Can't connect to Wi-Fi"
         ip = ""
 
+    if not "unique_clients" in r:
+        output_string = "Error from API.\nRun pihole-dashboard-draw\nfor details."
+        draw_dashboard(output_string)
+        output_error = "API Response: {}".format(r)
+        sys.exit(output_error)
+
     unique_clients = r['unique_clients']
     ads_blocked_today = r['ads_blocked_today']
 
